@@ -9,6 +9,7 @@ from typing import List, Tuple, Optional
 # module
 from avwx.current.base import Report, get_wx_codes
 from avwx.parsing import core, sanitization, speech, summary
+from avwx.parsing.remarks import parse as parse_remarks
 from avwx.parsing.translate.taf import translate_taf
 from avwx.static.core import FLIGHT_RULES, IN_UNITS, NA_UNITS
 from avwx.static.taf import TAF_RMK, TAF_NEWLINE, TAF_NEWLINE_STARTSWITH
@@ -125,6 +126,9 @@ def get_type_and_times(
             and data[0][5:].isdigit()
         ):
             start_time, end_time = data.pop(0).split("/")
+        # 120000
+        elif len(data[0]) == 6 and data[0].isdigit() and data[0][-2:] == "00":
+            start_time = data.pop(0)[:4]
         # FM120000
         elif len(data[0]) > 7 and data[0].startswith("FM"):
             report_type = "FROM"
@@ -276,6 +280,7 @@ def parse(
     station: str, report: str, issued: date = None
 ) -> Tuple[Optional[TafData], Optional[Units]]:
     """Returns TafData and Units dataclasses with parsed data and their associated units"""
+    # pylint: disable=too-many-locals
     if not report:
         return None, None
     valid_station(station)
@@ -338,6 +343,7 @@ def parse(
         station=station,
         time=core.make_timestamp(time, target_date=issued),
         remarks=remarks,
+        remarks_info=parse_remarks(remarks),
         forecast=parsed_lines,
         start_time=start_time,
         end_time=end_time,
@@ -418,6 +424,7 @@ def parse_lines(
 
 def parse_line(line: str, units: Units, issued: date = None) -> TafLineData:
     """Parser for the International TAF forcast variant"""
+    # pylint: disable=too-many-locals
     data = core.dedupe(line.split())
     data = sanitization.sanitize_report_list(data, remove_clr_and_skc=False)
     sanitized = " ".join(data)
@@ -461,7 +468,11 @@ class Taf(Report):
     data: Optional[TafData] = None
     translations: Optional[TafTrans] = None  # type: ignore
 
-    def _post_update(self):
+    async def _post_update(self):
+        self.data, self.units = parse(self.icao, self.raw, self.issued)
+        self.translations = translate_taf(self.data, self.units)
+
+    def _post_parse(self):
         self.data, self.units = parse(self.icao, self.raw, self.issued)
         self.translations = translate_taf(self.data, self.units)
 
