@@ -7,7 +7,9 @@ from typing import List, Optional
 
 # module
 import avwx.parsing.translate.base as _trans
-from avwx.parsing import core, remarks
+from avwx.parsing import core
+
+from avwx.parsing.translate import remarks
 from avwx.static.taf import ICING_CONDITIONS, TURBULENCE_CONDITIONS
 from avwx.structs import TafData, TafLineTrans, TafTrans, Units
 
@@ -84,7 +86,7 @@ def min_max_temp(temp: Optional[str], unit: str = "C") -> str:
         temp_type = "Minimum"
     else:
         return ""
-    value, time = temp[2:].replace("M", "-").replace("Z", "").split("/")
+    value, time = temp[2:].replace("M", "-").replace("Z", "").strip("/").split("/")
     if len(time) > 2:
         time = time[:2] + "-" + time[2:]
     translation = _trans.temperature(core.make_number(value), unit)
@@ -120,5 +122,5 @@ def translate_taf(wxdata: TafData, units: Units) -> TafTrans:
         forecast=forecast,
         max_temp=min_max_temp(wxdata.max_temp, units.temperature),
         min_temp=min_max_temp(wxdata.min_temp, units.temperature),
-        remarks=remarks.translate(wxdata.remarks),
+        remarks=remarks.translate(wxdata.remarks, wxdata.remarks_info),
     )
