@@ -35,6 +35,7 @@ M_IN_REGIONS = ["MD", "MG", "MH", "MK", "MN", "MP", "MR", "MS", "MU", "MW", "MZ"
 NA_UNITS = {
     "altimeter": "inHg",
     "altitude": "ft",
+    "accumulation": "in",
     "temperature": "C",
     "visibility": "sm",
     "wind_speed": "kt",
@@ -43,6 +44,7 @@ NA_UNITS = {
 IN_UNITS = {
     "altimeter": "hPa",
     "altitude": "ft",
+    "accumulation": "in",
     "temperature": "C",
     "visibility": "m",
     "wind_speed": "kt",
@@ -57,15 +59,39 @@ CLOUD_LIST = ["FEW", "SCT", "BKN", "OVC"]
 #: Dictionary of cardinal direction values
 CARDINALS = {
     "N": 360,
+    "NORTH": 360,
     "NE": 45,
     "E": 90,
+    "EAST": 90,
     "SE": 135,
     "S": 180,
+    "SOUTH": 180,
     "SW": 225,
     "W": 270,
+    "WEST": 270,
     "NW": 315,
 }
 
+#: Dictionary of tertiary cardinal directions to degree values with North at 0
+CARDINAL_DEGREES = {
+    "NNE": 22.5,
+    "NE": 45,
+    "ENE": 67.5,
+    "E": 90,
+    "ESE": 112.5,
+    "SE": 135,
+    "SSE": 157.5,
+    "S": 180,
+    "SSW": 202.5,
+    "SW": 225,
+    "WSW": 247.5,
+    "W": 270,
+    "WNW": 292.5,
+    "NW": 315,
+    "NNW": 337.5,
+    "N": 0,
+}
+
 #: Dictionary associating WX codes with descriptions
 WX_TRANSLATIONS = {
     "BC": "Patchy",
@@ -129,7 +155,13 @@ CLOUD_TRANSLATIONS = {
 }
 
 #: Units required to be translated in order to be spoken properly
-SPOKEN_UNITS = {"sm": "mile", "km": "kilometer", "C": "Celsius", "F": "Fahrenheit"}
+SPOKEN_UNITS = {
+    "sm": "mile",
+    "km": "kilometer",
+    "C": "Celsius",
+    "F": "Fahrenheit",
+    "kt": "knot",
+}
 
 #: Dictionary associating algebraic signs with their spoken version
 NUMBER_REPL = {
@@ -163,6 +195,10 @@ SPECIAL_NUMBERS = {
     "P6SM": (None, "greater than six"),
     "P99": (None, "greater than nine nine"),
     "VRB": (None, "variable"),
+    "CLM": (0, "calm"),
+    "SFC": (0, "surface"),
+    "STNR": (0, "stationary"),
+    "FRZLVL": (None, "freezing level"),
 }
 
 #: Static remarks translation elements
@@ -179,9 +215,10 @@ REMARKS_ELEMENTS = {
     "PRESRR": "Pressure Rising Rapidly",
     "PWINO": "Precipitation identifier information not available",
     "RVRNO": "Runway Visual Range missing",
+    "SLPNO": "Sea level pressure not available",
     "SOG": "Snow on the ground",
     "TSNO": "Thunderstorm information not available",
 }
 
 #: Static remarks translation groups
-REMARKS_GROUPS = {" ACFT MSHP ": "Aircraft mishap"}
+REMARKS_GROUPS = {"ACFT MSHP": "Aircraft mishap"}
